@@ -19,8 +19,8 @@
 from django.template import defaultfilters as filters
 from django.urls import reverse
 from django.utils.http import urlencode
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 
 from horizon import tables
 from horizon.templatetags import sizeformat
@@ -33,17 +33,17 @@ class DeleteFlavor(tables.DeleteAction):
 
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
-            u"Delete Flavor",
-            u"Delete Flavors",
+        return ngettext_lazy(
+            "Delete Flavor",
+            "Delete Flavors",
             count
         )
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
-            u"Deleted Flavor",
-            u"Deleted Flavors",
+        return ngettext_lazy(
+            "Deleted Flavor",
+            "Deleted Flavors",
             count
         )
 
